<?php

namespace Drupal\cookiebot_gtm\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class CookiebotGtmConfigForm.
 */
class CookiebotGtmConfigForm extends ConfigFormBase {

  /**
   * Drupal\Core\Language\LanguageManagerInterface definition.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  private $languageManager;

  /**
   * Class constructor.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LanguageManagerInterface $languageManager) {
    parent::__construct($config_factory);
    $this->languageManager = $languageManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('language_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'cookiebot_gtm.cookiebot_gtm_config',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cookiebot_gtm_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('cookiebot_gtm.cookiebot_gtm_config');
    $form['cbid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Cookiebot Domain Group Id (CBID)'),
      '#description' => $this->t('This ID looks like 00000000-0000-0000-0000-000000000000. You can find it in the Cookiebot Manager on the &#039;Your scripts&#039; tab.'),
      '#maxlength' => 255,
      '#size' => 64,
      '#default_value' => $config->get('cbid'),
    ];
    $form['use_multilingual'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use the multilingual Cookiebot'),
      '#description' => $this->t('When you enable this checkbox the current language is used for the Cookiebot banner.'),
      '#default_value' => $config->get('use_multilingual'),
    ];
    $form['use_multilingual_gtm_id'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use a different Google Tag Manager ID per language.'),
      '#default_value' => $config->get('use_multilingual_gtm_id'),
    ];
    $form['gtm_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google Tagmanager Container ID'),
      '#description' => $this->t('Your Google Tagmanager Container ID that looks like GTM-XXXXXXX'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('gtm_id'),
      '#states' => [
        'visible' => [
          ':input[name="use_multilingual_gtm_id"]' => ['checked' => FALSE],
        ],
      ],
    ];

    $form['languages'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Google Tagmanager Container ID per language'),
      '#states' => [
        'visible' => [
          ':input[name="use_multilingual_gtm_id"]' => ['checked' => TRUE],
        ],
      ],
    ];

    /** @var \Drupal\Core\Language\Language $language */
    foreach ($this->languageManager->getLanguages() as $language) {
      $title = $this->t('@lang Google Tagmanager Container ID', ['@lang' => $language->getName()]);
      $fieldName = 'gtm_id_' . $language->getId();

      $form['languages'][$fieldName] = [
        '#type' => 'textfield',
        '#title' => $title,
        '#description' => $this->t('Your @lang Google Tagmanager Container ID that looks like GTM-XXXXXXX', ['@lang' => $language->getName()]),
        '#maxlength' => 64,
        '#size' => 64,
        '#default_value' => $config->get($fieldName),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $config = $this->config('cookiebot_gtm.cookiebot_gtm_config');
    $config->set('cbid', $form_state->getValue('cbid'))
      ->set('use_multilingual', $form_state->getValue('use_multilingual'))
      ->set('use_multilingual_gtm_id', $form_state->getValue('use_multilingual_gtm_id'))
      ->set('gtm_id', $form_state->getValue('gtm_id'));

    /** @var \Drupal\Core\Language\Language $language */
    foreach ($this->languageManager->getLanguages() as $language) {
      $config->set('gtm_id_' . $language->getId(), $form_state->getValue('gtm_id_' . $language->getId()));
    }

    $config->save();
  }

}
